@@ -268,7 +268,7 @@ class FPLAnalytics:
 
     def findPlayer(self, pattern):
         
-        players = [p.strip() for p in pattern.split(' ')]
+        players = [p.strip() for p in pattern.split(',')]
         stats = self.getPlayerSummary()
         stats['web_name_decode'] = stats[['web_name']].apply(lambda x: unidecode.unidecode(x['web_name']), axis = 1)
         stats['full_name_decode'] = stats[['full_name']].apply(lambda x: unidecode.unidecode(x['full_name']), axis = 1)
@@ -279,7 +279,7 @@ class FPLAnalytics:
             if df.shape[0] == 0:
                 df = stats[stats['web_name_decode'].str.match(p, flags=re.IGNORECASE)]
             if df.shape[0] == 0:
-                df = stats[stats['full_name_decode'].str.match(p, flags=re.IGNORECASE, regex=True)]
+                df = stats[stats['full_name_decode'].str.match(p, flags=re.IGNORECASE)]
             if df.shape[0] == 0:
                 df = stats[stats['web_name_decode'].str.contains(p, flags=re.IGNORECASE, regex=True)]
             result = pd.concat([result, df])
